************************************
* ANALYSIS: ELECTORAL VIOLENCE SURVEY DATA 
* Ordered logit models

* Carl Müller-Crepon,
* 25.4.2018
************************************

* Data
use data\afrobarometer.dta, clear
encode survey_sponsor, generate(survey_sponsor_d)


*interactions:
gen epr_pr = epr_polar*pr
gen age_sq = age^2


* Globals
global esttab_notes "addnotes("\parbox[t]{.95\textwidth}{\phantom{Note} \vspace{-.2cm} \leavevmode \\ \textit{Notes:} Ordered logistical regression models. Control variables include the district population (logged), and urban and female dummy, age and its square, as well as the respondent's education. Standard errors clustered on the district-level in parentheses.}")"
global esttab "dropped(0) style(tex) depvars nogaps replace  star(* 0.1 ** 0.05 *** 0.01) nonotes booktabs se numbers label  alignment(D{.}{.}{-1}) eql(,none) "
global stats "stat( sample fe contr N chi2,  layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}") label( "Sample" "Country-round FE" "Controls" "Observations" "\(\chi^2\)"))"


*labels

lab var epr_polar "Ethno-pol. polarization"
lab var log_pop "Population (log)"
lab var fear_eviol "Fear"
lab var epr_pr "Ethno-pol. polarization $\times$ PR"
lab var nightlights_pp "Nightlights p.c."
lab var polar "Ethnic polarization"
lab var urb_pop_ln "Urban population (log)"

*Analysis with logit models
*   Produces Table A17

*Main table
eststo clear
	eststo: ologit   fear_eviol epr_polar  log_pop urban  sex age educ i.cowround  if majoritarian==1, cl(district_id)
	estadd local sample "Maj. \& Mix.", replace
	estadd local fe "yes" , replace
	estadd local contr "yes" , replace
	eststo: ologit   fear_eviol epr_polar  log_pop urban  sex age educ i.cowround  if majoritarian==0, cl(district_id)
	estadd local sample "PR", replace
	estadd local fe "yes" , replace
	estadd local contr "yes" , replace
	eststo: ologit   fear_eviol epr_polar epr_pr  c.log_pop##c.pr c.urban##c.pr  c.sex##c.pr c.age##c.pr c.educ##c.pr  i.cowround  , cl(district_id)
	estadd local sample "all", replace
	estadd local fe "yes" , replace
	estadd local contr "yes" , replace
	
	global these_notes "addnotes("\parbox[t]{.76\columnwidth}{\phantom{Note}  \vspace{-.2cm} \leavevmode \\ \textit{Notes:}  Ordered logistical regression models. Control variables include the district population (logged), and urban and female dummy, age and its square, as well as the respondent's education.  Model 3 also includes interactions of all covariates with the PR dummy. Standard errors clustered on the district-level in parentheses. Significance codes: $^{*}p<0.1; ^{**}p<0.05; ^{***}p<0.01$}")"

	esttab using "results\tables\tablea17.tex" , ///
				$esttab $these_notes $stats ///
				ti("Local ethno-political polarization and fear: Ordered logit} \label{tab.ab.main.log") ///
				drop(*cowround* *cut* *log_pop* *urban* *educ* *sex* *age* pr) ///
				order( epr* ) 
	

*Robustness checks
*   Produces Table A18
global stats "stat( sample sample2 addc fe contr N chi2,  layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}") label( "Sample" "   " "Add. controls" "Country-round FE" "Controls" "Observations" "\(\chi^2\)"))"
global these_notes "addnotes("\parbox[t]{.76\textwidth}{\phantom{Note}  \vspace{-.2cm} \leavevmode \\ \textit{Notes:} Ordered logistical regression models. Control variables include the district population (logged), and urban and female dummy, age and its square, as well as the respondent's education. Standard errors clustered on the district-level in parentheses.}")"


eststo clear
	eststo: ologit   fear_eviol epr_polar nightlights_pp polar urb_pop_ln sex age educ log_pop urban i.cowround  if majoritarian==1, cl(district_id)
	estadd local sample "Maj. \& Mix.", replace
	estadd local sample2 "", replace
	estadd local addc "", replace
	estadd local fe "yes" , replace
	estadd local contr "yes" , replace
	eststo: ologit   fear_eviol epr_polar sex age educ  log_pop urban i.cowround  if majoritarian==1 & year>=map_from, cl(district_id)
	estadd local sample "Maj. \& Mix.", replace
	estadd local sample2 "\$ t \geq t_{SIDE}\$", replace
	estadd local addc "", replace
	estadd local fe "yes" , replace
	estadd local contr "yes" , replace
	eststo: ologit   fear_eviol epr_polar sex age educ  log_pop urban i.cowround same_language i.survey_sponsor_d others_present others_influence others_check  if majoritarian==1, cl(district_id)
	estadd local sample "Maj. \& Mix.", replace
	estadd local sample2 "", replace
	estadd local addc "Quality items", replace
	estadd local fe "yes" , replace
	estadd local contr "yes" , replace
	
	esttab using "results\tables\tablea18.tex" , ///
				$esttab $these_notes $stats ///
				ti("Local ethno-political polarization and fear, robustness checks: Ordered logit} \label{tab.ab.rob.log") ///
				keep(epr_polar nightlights_pp polar urb_pop_ln) ///
				order( epr_polar nightlights_pp polar urb_pop_ln ) substitute(\_ _)


*Uganda and Nigeria ######################################################
*   Produces Table A19

* Load data
use data\afrobarometer_niguga.dta, clear

* Generate some variables
gen age_sq = age^2

* Label Variables
lab var electhreat "\sc{Personal threat:\\ frequency}"
lab var electhreat_safe "\sc{Personal threat:\\safety}"
lab var electhreatcom "\sc{Community threat\\ frequency}"
lab var electhreatcom_safe "\sc{Community threat:\\safety}"

lab var epr_polar "Ethno-pol. polarization"
lab var log_pop "Population (log)"

* Specification
global stats "stat( sample model fe contr N chi2,  layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}") label( "Sample" "Model" "Country-round FE" "Controls" "Observations" "\(\chi^2\)"))"

* Estimate & save
eststo clear
	eststo: ologit   electhreat epr_polar sex age educ log_pop urban i.cowround  if majoritarian==1, cl(district_id)
	estadd local sample "NIG \& UGA", replace
	estadd local model "ologit" , replace
	estadd local fe "yes" , replace
	estadd local contr "yes" , replace
	eststo: logit   electhreat_safe epr_polar sex age educ log_pop urban i.cowround  if majoritarian==1, cl(district_id)
	estadd local sample "NIG \& UGA", replace
	estadd local model "logit" , replace
	estadd local fe "yes" , replace
	estadd local contr "yes" , replace
	eststo: ologit   electhreatcom epr_polar sex age educ log_pop urban i.cowround  if majoritarian==1, cl(district_id)
	estadd local sample "NIG \& UGA", replace
	estadd local model "ologit" , replace
	estadd local fe "yes" , replace
	estadd local contr "yes" , replace
	eststo: logit   electhreatcom_safe epr_polar sex age educ log_pop urban i.cowround  if majoritarian==1, cl(district_id)
	estadd local sample "NIG \& UGA", replace
	estadd local model "logit" , replace
	estadd local fe "yes" , replace
	estadd local contr "yes" , replace
	esttab using "results\tables\tablea19.tex" , ///
				$esttab $esttab_notes $stats ///
				ti("Local ethno-political polarization and pre-election intimidation: (Ordered) logit} \label{tab.ab.niguga.log") ///
				drop(*cowround* *cut* sex age educ urban log_pop) ///
				order( epr_polar log_pop urban ) 
	
		
